Struct GCPluginConfig
pub struct GCPluginConfig(GCPluginConfig);Expand description
Zero cost abstraction over the GCPluginConfig ABI struct
Tuple Fields
0: GCPluginConfigImplementations
impl GCPluginConfig
impl GCPluginConfig
pub unsafe fn new(
own_datapoints: *const [GCDatapoint],
subscribed_datapoints: *const [GCDatapoint],
callbacks: *const sGCJsonCallbacks,
) -> Self
pub unsafe fn new( own_datapoints: *const [GCDatapoint], subscribed_datapoints: *const [GCDatapoint], callbacks: *const sGCJsonCallbacks, ) -> Self
Create a new GCPluginConfig
Safety
The caller is responsible for ensuring the pointers are valid for the lifetime of the GCPluginConfig This also applies to own_datapoints and subscribed_datapoints!
pub fn get_own_datapoints(&self) -> &[GCDatapoint]
pub fn get_own_datapoints(&self) -> &[GCDatapoint]
Get the datapoints that the plugin is allowed to publish
pub fn get_subscribed_datapoints(&self) -> &[GCDatapoint]
pub fn get_subscribed_datapoints(&self) -> &[GCDatapoint]
Get the datapoints that the plugin is subscribed to